#!/usr/bin/env python3

import bornagain as ba
from bornagain import nm, deg, std_samples, std_simulations
import bornplot2 as bp2


def get_samples():
    ret = []
    material_particle = ba.HomogeneousMaterial("Particle", 1e-5, 0)
    for omega in [0, 30]:
        ff = ba.FormFactorPyramid4(10*nm, 4*nm, 70*deg)
        particle = ba.Particle(material_particle, ff)
        particle.setRotation(ba.RotationZ(omega*deg))
        sample = std_samples.sas_sample_with_particle(particle)
        sample.setInstanceName(r'$\omega=%d^\circ$' % omega)
        ret.append(sample)
    return ret


def run_simulations():
    ret = []
    for simulation in std_simulations.sas_multisample(get_samples()):
        simulation.simulate()
        result = simulation.result().relativeToMaximum()
        ret.append(bp2.NamedResult(result, simulation.instanceName()))
    return ret


bp2.make_plot_row(run_simulations(), "ff_Pyramid4")
# bp.save_results(namedResults, "ff_Pyramid4")
