#!/usr/bin/env python3
"""
Cylinder form factor in DWBA with beam divergence
"""
import bornagain as ba
from bornagain import ba_plot as bp, deg, nm


def get_sample():
    from bornagain import std_samples
    return std_samples.cylinders()


def get_simulation(sample, **simargs):
    beam = ba.Beam(1, 0.1*nm, ba.Direction(0.2*deg, 0))
    detector = ba.SphericalDetector(simargs['n'], 2*deg, 1*deg, 1*deg)
    simulation = ba.ScatteringSimulation(beam, sample, detector)
    distr_1 = ba.DistributionLogNormal(0.1*nm, 0.1)
    simulation.addParameterDistribution(
        ba.ParameterDistribution.BeamWavelength, distr_1, 5, 0)
    distr_2 = ba.DistributionGaussian(0.2*deg, 0.1*deg)
    simulation.addParameterDistribution(
        ba.ParameterDistribution.BeamInclinationAngle, distr_2, 5, 0)
    distr_3 = ba.DistributionGaussian(0, 0.1*deg)
    simulation.addParameterDistribution(
        ba.ParameterDistribution.BeamAzimuthalAngle, distr_3, 5, 0)
    return simulation


if __name__ == '__main__':
    plotargs, simargs = bp.kwargs_from_cmdline(sim_n=100)
    sample = get_sample()
    simulation = get_simulation(sample, **simargs)
    result = simulation.simulate()
    bp.plot_simulation_result(result, **plotargs)
