#!/usr/bin/env python3
"""
Cylinder form factor in DWBA with constant background
"""
import bornagain as ba
from bornagain import ba_plot as bp, deg, nm


def get_sample():
    from bornagain import std_samples
    return std_samples.cylinders()


def get_simulation(sample, **simargs):
    beam = ba.Beam(1e6, 0.1*nm, ba.Direction(0.2*deg, 0))
    detector = ba.SphericalDetector(simargs['n'], 2*deg, 1*deg, 1*deg)
    simulation = ba.ScatteringSimulation(beam, sample, detector)
    background = ba.ConstantBackground(1.0e+03)
    simulation.setBackground(background)
    return simulation


if __name__ == '__main__':
    plotargs, simargs = bp.kwargs_from_cmdline(sim_n=100)
    sample = get_sample()
    simulation = get_simulation(sample, **simargs)
    result = simulation.simulate()
    bp.plot_simulation_result(result, **plotargs)
