#!/usr/bin/env python3
"""
Basic example of a DWBA simulation of a GISAS experiment:
Scattering by a dilute random assembly of cylinders on a substrate.
"""
import bornagain as ba
from bornagain import ba_plot as bp, deg, nm


def get_sample():
    from bornagain import std_samples
    return std_samples.cylinders()


def get_simulation(sample, **simargs):
    # Define beam
    wavelength = 0.1*nm
    alpha_i = 0.2*deg
    beam = ba.Beam(1, wavelength, ba.Direction(alpha_i, 0))

    # Define detector
    nPix = 200  # pixels per direction
    detector = ba.SphericalDetector(nPix, -2*deg, 2*deg, nPix, 0, 3*deg)

    return ba.ScatteringSimulation(beam, sample, detector)


if __name__ == '__main__':
    plotargs, simargs = bp.kwargs_from_cmdline(sim_n=0)
    sample = get_sample()
    simulation = get_simulation(sample, **simargs)
    result = simulation.simulate()
    bp.plot_simulation_result(result, **plotargs)
