#!/usr/bin/env python3
"""
Basic example of specular reflectometry simulation with BornAgain.
The sample consists of 20 alternating Ti and Ni layers.
Variant with explicit function get_simulation.
"""

import bornagain as ba
from bornagain import ba_plot as bp, deg, angstrom, std_samples


def get_sample():
    return std_samples.alternating_layers()


def get_simulation(sample, scan_size=500):
    """
    A standard specular simulation setup.
    """
    simulation = ba.SpecularSimulation()
    scan = ba.AlphaScan(1.54*angstrom, scan_size, 0, 2*deg)
    simulation.setScan(scan)
    simulation.setSample(sample)
    return simulation


if __name__ == '__main__':
    plotargs, simargs = bp.kwargs_from_cmdline(sim_n=0)
    sample = get_sample()
    simulation = get_simulation(sample, **simargs)
    result = simulation.simulate()
    bp.plot_simulation_result(result, **plotargs)
