#!/usr/bin/env python3
"""
An example of defining reflectometry instrument
for time of flight experiment. In this example
we will use purely qz-defined beam,
without explicitly specifying
incident angle or a wavelength.
Note that these approaches work with SLD-based
materials only.
"""
import numpy as np
import bornagain as ba
from bornagain import ba_plot as bp, std_samples


def get_sample():
    return std_samples.alternating_layers()


def get_simulation(sample, scan_size=500):
    """
    Defines and returns specular simulation
    with a qz-defined beam
    """
    qzs = np.linspace(0.01, 1, scan_size)  # qz-values
    scan = ba.QzScan(qzs)
    simulation = ba.SpecularSimulation()
    simulation.setScan(scan)
    simulation.setSample(sample)
    return simulation


if __name__ == '__main__':
    plotargs, simargs = bp.kwargs_from_cmdline(sim_n=0)
    sample = get_sample()
    simulation = get_simulation(sample, **simargs)
    result = simulation.simulate()
    bp.plot_simulation_result(result, **plotargs)
