//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/FormFactorCylinder.cpp
//! @brief     Implements class FormFactorCylinder.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Sample/HardParticle/FormFactorCylinder.h"
#include "Base/Math/Bessel.h"
#include "Base/Math/Constants.h"
#include "Base/Math/Functions.h"
#include "Sample/Shapes/DoubleEllipse.h"

FormFactorCylinder::FormFactorCylinder(const std::vector<double> P)
    : IFormFactor(P)
    , m_radius(m_P[0])
    , m_height(m_P[1])
{
    checkNodeArgs();
    // TODO improve!
    m_shape3D = std::make_unique<DoubleEllipse>(m_radius, m_radius, m_height, m_radius, m_radius);
}

FormFactorCylinder::FormFactorCylinder(double radius, double height)
    : FormFactorCylinder(std::vector<double>{radius, height})
{
}

complex_t FormFactorCylinder::formfactor_at_bottom(C3 q) const
{
    const double R = m_radius;
    const double H = m_height;

    const complex_t qH2 = q.z() * H / 2.;
    const complex_t qR = std::sqrt(q.x() * q.x() + q.y() * q.y()) * R;

    const complex_t axial_part = H * Math::sinc(qH2);
    const complex_t radial_part = M_TWOPI * R * R * Math::Bessel::J1c(qR);

    return radial_part * axial_part * exp_I(qH2);
}
