#!/bin/env python3
"""
"""

import re, subprocess, sys
import os
import glob
import bornagain as ba

def run_simulation():
    """
    Runs simulation and returns resulting intensity map.
    """

    # create minified simulation object
    global simulationObject
    simulation = get_minified_simulation()

    # INJECTION HERE: replacing get_simulation() method of example with local method
    example.get_simulation = adjusted_simulation
    simulation.simulate()
    return simulation.result()


def save_result(result, filename):
    """
    Writing result to the file with given name into test output directory.
    """
    try:
        ba.IntensityDataIOFactory.writeSimulationResult(result, filename)
    except Exception as err:
        print("Exception caught, failed to write file", err)


def check_result(result, example_name):
    print("Checking results for '{}':".format(example_name), flush=True)
    reffile = os.path.join(REFERENCE_DIR, example_name+".int.gz")
    print(" - reference data: '{}'".format(reffile), flush=True)
    ok = ba.agreesWithReference(result, reffile, TOLERANCE)
    if not ok:
        reffile_basename = os.path.basename(reffile)
        outname = os.path.join(OUTPUT_DIR, reffile_basename)
        print("=> no agreement; going to save new result in", outname, flush=True)
        save_result(result, outname)
        return 1
    return 0


def process_example():
    result = run_simulation()

    nfailures = 0
    if type(result) is dict:
        for dict_key, subresult in result.items():
            nfailures += check_result(subresult, REFERENCE_NAME + "." + str(dict_key))
    else:
        nfailures += check_result(result, REFERENCE_NAME)

    return nfailures


def main(script, reference, refdir, outdir, sim_n, tolerance):
    reffile = os.path.join(refdir, reference+".int.gz")
    newfile = os.path.join(outdir, reference+".int.gz")
    os.makedirs(os.path.dirname(newfile), exist_ok=True)

    cmd = f'{script} sim_n={sim_n} datfile={newfile}'
    print(cmd, flush=True)
    try:
        ret = subprocess.run(cmd.split(), check=True, timeout=3)
    except Exception as err:
        print("subprocess raises", err)
        return 1
    print("command executed", flush=True)

    ok = ba.filesAgree(newfile, reffile, tolerance)
    if not ok:
        print(f"=> no agreement; new result saved in {newfile}", flush=True)
        return 1
    return 0


if __name__ == '__main__':
    if len(sys.argv) != 7:
        raise Exception(f'{sys.argv[0]}: invalid arguments. Expected: ' +
                        'script reference refdir outdir sim_n tolerance')
    script, reference, refdir, outdir = sys.argv[1:5]
    sim_n = int(sys.argv[5])
    tolerance = float(sys.argv[6])
    ret = main(script, reference, refdir, outdir, sim_n, tolerance)
    sys.exit(ret)
