# Configure one component library.

function(MakeLib name lib tmpdir withPython)

    if(withPython)
        if((CLANG) OR (GCC))
            # suppress warnings from auto-generated code (last updated for Swig 4.0.1)
            set_source_files_properties(${AUTO_DIR}/lib${lib}_wrap.cpp
                PROPERTIES COMPILE_OPTIONS
                "\
-Wno-unused-parameter;\
-Wno-missing-field-initializers;\
-Wno-sometimes-uninitialized;\
-Wno-deprecated-declarations")
        endif()

        list(APPEND source_files ${AUTO_DIR}/lib${lib}_wrap.cpp)
    endif()

    add_library(${lib} SHARED ${source_files})
    set_target_properties(${lib} PROPERTIES
        PREFIX ${libprefix}
        SUFFIX ${libsuffix}
        OUTPUT_NAME ${lib}
        # eg., libBornAgainBase.so
        _BASEFILENAME ${libprefix}${lib}${libsuffix})

    # NOTE on run-time linking:
    # - Linux:
    # See <https://en.wikipedia.org/wiki/Rpath>
    # - MacOS:
    # See 'Run-Path Dependent Libraries' <https://apple.co/3HVbMWm> and `dlopen` manpage.
    # - Windows:
    # On Windows, run-time dependencies are located in the directory from which
    # the application is loaded and then the `PATH`;
    # see 'Dynamic-Link Library Search Order'
    # <https://docs.microsoft.com/en-us/windows/win32/dlls/dynamic-link-library-search-order>

    if(APPLE AND BA_APPLE_BUNDLE)
        # Add proper RPATHs as hints to load the dependencies at run-time
        set(link_flags "-Wl,-rpath,@loader_path -Wl,-rpath,@loader_path/extra")
        set_target_properties(${lib} PROPERTIES LINK_FLAGS ${link_flags})
    endif()

    if(LINUX)
        # Add proper RPATHs as hints to load the dependencies at run-time
        # NOTE: Unlike `RUNPATH`, `RPATH` is searched for transitive dependencies;
        # ie. paths in RPATH will be considered for everything that is
        # dynamically loaded, even dependencies of dependencies.
        # see <https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=847298>
        set(link_flags "-Wl,--disable-new-dtags,-rpath,\$ORIGIN:\$ORIGIN/extra")
        set_target_properties(${lib} PROPERTIES LINK_FLAGS ${link_flags})
    endif(LINUX)

    if(withPython)
        SwigLib(${name} ${lib} ${tmpdir})
        if(BA_PY_PACKAGE)
            # add the BornAgain library to the Python wheel
            add_library_to_wheel(${lib})
        endif(BA_PY_PACKAGE)
    endif()

    install(TARGETS ${lib}
        LIBRARY DESTINATION ${destination_lib}
        RUNTIME DESTINATION ${destination_lib}
        COMPONENT Libraries)

    if(BA_CPP_API)
        foreach(file ${include_files})
            get_filename_component(dir ${file} DIRECTORY)
            install(FILES ${file} DESTINATION ${destination_include}/${name}/${dir})
        endforeach()
    endif()

endfunction()
