# Python dependencies

# find Python platform with/without a given path
include("multipython/FindCustomPython3")
if(BA_PY_PLATFORM)
    message(STATUS "PyDependences: Custom Python platform path = '${BA_PY_PLATFORM}'")
    find_custom_python3(PATHS "${BA_PY_PLATFORM}" VERBOSE)
else(BA_PY_PLATFORM)
    message(STATUS "PyDependences: Using default Python platform")
    find_custom_python3(DEFAULT_PATH VERBOSE)
endif(BA_PY_PLATFORM)

# check presence of some Python modules
message(STATUS "Searching required Python packages...")
foreach(pkg build numpy setuptools wheel matplotlib)
    message(STATUS "Python package ${pkg}")
    execute_process(
        COMMAND ${Python3_EXECUTABLE}
        ${CMAKE_SOURCE_DIR}/cmake/tests/find_pkg.py ${pkg}
        RESULT_VARIABLE PKG_FOUND)
    if(NOT PKG_FOUND EQUAL 0)
        message(FATAL_ERROR "Python package ${pkg} not found")
    endif()
endforeach()

# configure SWIG bindings
if(CONFIGURE_BINDINGS)
    find_package(SWIG 4.0 REQUIRED)
    include(${SWIG_USE_FILE})
    message(STATUS "Found SWIG version ${SWIG_VERSION} at ${SWIG_EXECUTABLE} "
        "with flags '${SWIG_FLAGS}'; CMake definitions in ${SWIG_USE_FILE}")

    if(CONFIGURE_PYTHON_DOCS)
        find_package(Doxygen REQUIRED)
    endif()
endif(CONFIGURE_BINDINGS)

if(BA_PY_PACKAGE)
    # define a target to make a Python wheel
    include("multipython/MakePythonWheel")
    make_python_wheel(
        Py3_VERSION ${Python3_VERSION}
        Py3_EXECUTABLE "${Python3_EXECUTABLE}"
        Py3_INCLUDE_DIRS "${Python3_INCLUDE_DIRS}"
        Py3_LIBRARY_DIRS "${Python3_LIBRARY_DIRS}"
        )
endif(BA_PY_PACKAGE)
