+++
title = "Bipyramid4"
+++

### FormFactorBipyramid4

A truncated pyramid (frustum) with quadratic base.

<img src="../3d/Bipyramid4.png" width="30%" >
<img src="../cut/Bipyramid4_xy.svg" width="30%">
<img src="../cut/Bipyramid4_xz.svg" width="30%">

#### Constructor

{{< highlight python >}}
FormFactorBipyramid4(L, H, r_H, alpha)
{{< /highlight >}}

Parameters:
- L, edge length of the shared quadratic base
- H, height of the bottom pyramid
- r_H, height ratio $r_{H}$ between the top and bottom pyramid
- alpha, dihedral angle $\alpha$ between the base and a side face.

Constraint:

$H \le \dfrac{\tan\alpha}{2} L \quad $ and $ \quad r_{H} H \le \dfrac{\tan\alpha}{2} L$

#### Usage

As for any other [Form factor](/py/sample/particle/ff).

#### Implementation

Class [FormFactorBipyramid4]({{% ref-src "Sample/HardParticle/FormFactorBipyramid4.h" %}})
inherits from the interface class
[IFormFactor]({{% ref-src "Sample/Particle/IFormFactor.h" %}}).

Form factor computation is based on the generic form factor of a polyhedron
provided by [libheinz](https://jugit.fz-juelich.de/mlz/libheinz).

Volume [has been validated]({{% ref-src "Tests/Unit/Sample/FormFactorBasicTest.cpp" %}})
against
$$V=\dfrac{L^3\tan\alpha}{6}\Big[2-\Big(1-\dfrac{2H}{L\tan\alpha}\Big)^3-\Big(1-\dfrac{2r_{H}H}{L\tan\alpha}\Big)^3\Big].$$

#### Related shapes

More special:
- [Pyramid4](/py/sample/particle/ff/hard/pyramid4), if $r_H \to \infty$.
- [Box](/py/sample/particle/ff/hard/box), if $\alpha=90^{\circ}$.

#### History

Was incorrectly named "Cuboctahedron" up to BornAgain 1.19.

Agrees with "Bipyramid4" form factor of IsGISAXS [[manual](/lit/lazzari2006), Eq. 2.34;
[Renaud 2009](/lit/renaud2009), Eq. 218],
except for different parametrization $L = 2R_{IsGISXAXS}$. Since BornAgain-1.6 implemented using the generic polyhedron form factor [[Wuttke 2021](/lit/wuttke2021)].
