+++
title = "Box"
+++

### FormFactorBox

A rectangular cuboid.

<img src="../3d/Box.png" width="30%" >
<img src="../cut/Box_xy.svg" width="30%">
<img src="../cut/Box_xz.svg" width="30%">

#### Constructor

{{< highlight python >}}
FormFactorBox(L, W, H)
{{< /highlight >}}

Parameters:
- L, length of the base
- W, width of the base
- H, height

#### Usage

As for any other [Form factor](/py/sample/particle/ff).

#### Implementation

Class [FormFactorBox]({{% ref-src "Sample/HardParticle/FormFactorBox.h" %}})
inherits from the interface class
[IFormFactor]({{% ref-src "Sample/Particle/IFormFactor.h" %}}).

Form factor is computed as
$$F(\mathbf{q})=LWH \space \exp\Big(iq_{z}\dfrac{H}{2}\Big) \space \text{sinc}\Big(q_{x}\dfrac{L}{2}\Big) \space \text{sinc}\Big(q_{y}\dfrac{W}{2}\Big) \space \text{sinc}\Big(q_{z}\dfrac{H}{2}\Big).$$

Volume [has been validated]({{% ref-src "Tests/Unit/Sample/FormFactorBasicTest.cpp" %}})
against
$$V=LWH.$$

#### Related shapes

More general:
- [Pyramid2](/py/sample/particle/ff/hard/pyramid2) or [Pyramid4](/py/sample/particle/ff/hard/pyramid4), if sides are not vertical.

More special:
<!--- [Bar](/py/sample/particle/ff/hard/bar), if elongated in L or W direction.-->
- Bar, if elongated in L or W direction.

Modified cubes:
<!--- [TruncatedCube](/py/sample/particle/ff/hard/truncatedcube), if $L=W=H$ and corners are facetted.-->
- TruncatedCube, if $L=W=H$ and corners are facetted.
<!--- [CantellatedCube](/py/sample/particle/ff/hard/cantellatedcube), if $L=W=H$ and corners and edges are facetted.-->
- CantellatedCube, if $L=W=H$ and corners and edges are facetted.

#### History

Agrees with "Box" form factor of IsGISAXS [[manual](/lit/lazzari2006), Eq. 2.38;
[Renaud 2009](/lit/renaud2009), Eq. 214],
except for factors $1/2$ in the definition of parameters $L,\space W,\space H$.
