+++
title = "Cone"
+++

### FormFactorCone

A truncated cone (frustum) with circular base.

<img src="../3d/Cone.png" width="30%" >
<img src="../cut/Cone_xy.svg" width="30%">
<img src="../cut/Cone_xz.svg" width="30%">

#### Constructor

{{< highlight python >}}
FormFactorCone(R, H, alpha)
{{< /highlight >}}

Parameters:
- R, radius
- H, height
- alpha, angle $\alpha$ between the base and a side.

Constraint:

$H \le R \tan\alpha$

#### Usage

As for any other [Form factor](/py/sample/particle/ff).

#### Implementation

Class [FormFactorCone]({{% ref-src "Sample/HardParticle/FormFactorCone.h" %}})
inherits from the interface class
[IFormFactor]({{% ref-src "Sample/Particle/IFormFactor.h" %}}).

Computation involves numerical integration in radial direction,
$$F(\mathbf{q})=2\pi \exp(i \tilde{q_{z}} R) \tan\alpha \int_{R_H}^R d\rho\thinspace \rho^2
   \frac{J_1(q_{\parallel}\rho)}{q_{\parallel}\rho} e^{-i\tilde{q}_z \rho},$$

with notation
$$\quad  R_{H} := R-\dfrac{H}{\tan\alpha}, \quad
q_{||} := \sqrt{q_{x}^2 + q_{y}^2}, \quad
\tilde{q_{z}} := q_{z} \tan\alpha.$$

Volume [has been validated]({{% ref-src "Tests/Unit/Sample/FormFactorBasicTest.cpp" %}})
against
$$V=\dfrac{\pi}{3}\tan\alpha  \left( R^3 - R_H^3\right).$$

#### Related shapes

More special:
- [Cylinder](/py/sample/particle/ff/hard/cylinder), if $\alpha=90^{\circ}$.

#### History

Agrees with "Cone" form factor in IsGISAXS [[manual](/lit/lazzari2006), Eq. 2.28;
[Renaud 2009](/lit/renaud2009), Eq. 225], except for a substitution $z\to\rho$ in our expression for $F$.
