+++
title = "Cylinder"
+++

### FormFactorCylinder

An upright circular cylinder.

<img src="../3d/Cylinder.png" width="30%" >
<img src="../cut/Cylinder_xy.svg" width="30%">
<img src="../cut/Cylinder_xz.svg" width="30%">

#### Constructor

{{< highlight python >}}
FormFactorCylinder(R, H)
{{< /highlight >}}

Parameters:
- R, radius
- H, height

#### Usage

As for any other [Form factor](/py/sample/particle/ff).

#### Implementation

Class [FormFactorCylinder]({{% ref-src "Sample/HardParticle/FormFactorCylinder.h" %}})
inherits from the interface class
[IFormFactor]({{% ref-src "Sample/Particle/IFormFactor.h" %}}).

Form factor is computed as

$$ F(\mathbf{q})=2\pi R^2H \space \exp\Big(iq_z\dfrac{H}{2}\Big) \text{sinc}\Big(q_z\dfrac{H}{2}\Big)
\dfrac{J_1(q_{\parallel}R)}{q_{\parallel}R} $$
with the notation 
$$ q_{||} := \sqrt{q_x^2 + q_y^2}. $$

Volume [has been validated]({{% ref-src "Tests/Unit/Sample/FormFactorBasicTest.cpp" %}})
against
$$V=\pi R^2H.$$

#### Related shapes

More general:
- [Cone](/py/sample/particle/ff/hard/cone), if radius varies with z.
- [EllipsoidalCylinder](/py/sample/particle/ff/hard/ellipsoidalcylinder), if cross section is an ellipse.

#### History

This form factor is well known; it goes back to Lord Rayleigh.

In IsGISAXS, it has been implemented as form factor "Cylinder"
[[manual](/lit/lazzari2006), Eq. 2.27; [Renaud 2009](/lit/renaud2009), Eq. 223],
allowing for complex wavevectors.
