+++
title = "EllipsoidalCylinder"
+++

### FormFactorEllipsoidalCylinder

An upright cylinder whose cross section is an ellipse.

<img src="../3d/EllipsoidalCylinder.png" width="30%" >
<img src="../cut/EllipsoidalCylinder_xy.svg" width="30%">
<img src="../cut/EllipsoidalCylinder_xz.svg" width="30%">

#### Constructor

{{< highlight python >}}
FormFactorEllipsoidalCylinder(R_a, R_b, H)
{{< /highlight >}}

Parameters:
- R_a, radius $R_{a}$ in $x$ direction
- R_b, radius $R_{b}$ in $y$ direction
- H, height

#### Usage

As for any other [Form factor](/py/sample/particle/ff).

#### Implementation

Class [FormFactorEllipsoidalCylinder]({{% ref-src "Sample/HardParticle/FormFactorEllipsoidalCylinder.h" %}})
inherits from the interface class
[IFormFactor]({{% ref-src "Sample/Particle/IFormFactor.h" %}}).

Form factor is computed as

$$ F(\mathbf{q})=2\pi R_aR_b H \space \exp\Big(iq_z\dfrac{H}{2}\Big) \text{sinc}\Big(q_z\dfrac{H}{2}\Big) 
\dfrac{J_1(\gamma)}{\gamma} $$
with the notation 
$$ \gamma := \sqrt{(q_xR_a)^2 + (q_yR_b)^2}. $$

Volume [has been validated]({{% ref-src "Tests/Unit/Sample/FormFactorBasicTest.cpp" %}})
against
$$V=\pi R_aR_bH.$$

#### Related shapes

More special:
- [Cylinder](/py/sample/particle/ff/hard/cylinder), if cross section is circular.

#### History

Agrees with "Ellipsoid" form factor of IsGISAXS [[manual](/lit/lazzari2006), Eq. 2.41, wrongly labeled in Fig. 2.4] or "Ellipsoidal Cylinder" [[Renaud 2009](/lit/renaud2009), Eq. 224]
