+++
title = "Prism6"
+++

### FormFactorPrism6

A prism based on regular hexagon.

<img src="../3d/Prism6.png" width="30%" >
<img src="../cut/Prism6_xy.svg" width="30%">
<img src="../cut/Prism6_xz.svg" width="30%">

#### Constructor

{{< highlight python >}}
FormFactorPrism6(L, H)
{{< /highlight >}}

Parameters:
- R, edge of the regular hexagonal base
- H, height

#### Usage

As for any other [Form factor](/py/sample/particle/ff).

#### Implementation

Class [FormFactorPrism6]({{% ref-src "Sample/HardParticle/FormFactorPrism6.h" %}})
inherits from the interface class
[IFormFactor]({{% ref-src "Sample/Particle/IFormFactor.h" %}}).

Form factor is computed as

$$ F(\mathbf{q})=H \space \exp\Big(iq_z\dfrac{H}{2}\Big) \space \text{sinc}\Big(q_z\dfrac{H}{2}\Big) \space F_{||}(\mathbf{q}_{||}) $$

where the form factor $F_{||}(\mathbf{q}_{||}) $ computation is based on the generic form factor of a planar polygon with two-fold symmetry $(S_{2})$ provided by [libheinz](https://jugit.fz-juelich.de/mlz/libheinz).

Volume [has been validated]({{% ref-src "Tests/Unit/Sample/FormFactorBasicTest.cpp" %}})
against
$$ V=\dfrac{3\sqrt3}{2}HR^2. $$

#### Related shapes

More general:
- [Pyramid6](/py/sample/particle/ff/hard/pyramid6), if sides are not vertical.

#### History

Has been validated against the "Prism6" form factor of IsGISAXS [[manual](/lit/lazzari2006), Eq. 2.31; [Renaud 2009](/lit/renaud2009), Eq. 221], which has different parametrization and lacks a factor $H$ in $F(\mathbf{q})$.
Reimplemented in BornAgain 1.6 using the generic form factor of a polygonal prism with symmetry $S_{2}$ [[Wuttke 2021](/lit/wuttke2021)] to achieve numerical stability near the removable singularity at $q \to 0$.
