+++
title = "Pyramid2"
+++

### FormFactorPyramid2

A truncated pyramid with rectangular base.

<img src="../3d/Pyramid2.png" width="30%" >
<img src="../cut/Pyramid2_xy.svg" width="30%">
<img src="../cut/Pyramid2_xz.svg" width="30%">

#### Constructor

{{< highlight python >}}
FormFactorPyramid2(L, W, H, alpha)
{{< /highlight >}}

Parameters:
- L, edge length of the base
- W, edge width of the base
- H, height
- alpha, dihedral angle $\alpha$ between the base and a side face.

Constraint:

$H \le \dfrac{\tan\alpha}{2} min(L,W)$

#### Usage

As for any other [Form factor](/py/sample/particle/ff).

#### Implementation

Class [FormFactorPyramid2]({{% ref-src "Sample/HardParticle/FormFactorPyramid2.h" %}})
inherits from the interface class
[IFormFactor]({{% ref-src "Sample/Particle/IFormFactor.h" %}}).

Form factor computation is based on the generic form factor of a polyhedron
provided by [libheinz](https://jugit.fz-juelich.de/mlz/libheinz).

Volume [has been validated]({{% ref-src "Tests/Unit/Sample/FormFactorBasicTest.cpp" %}})
against
$$ V=H\Big[LW-\dfrac{(L+W)H}{\tan\alpha}+\dfrac{4}{3}\dfrac{H^2}{\tan^2\alpha}\Big]. $$

#### Related shapes

More special:
- [Pyramid4](/py/sample/particle/ff/hard/pyramid4), if $L=W$.
- [Box](/py/sample/particle/ff/hard/box), if $\alpha=90^{\circ}$.

#### History

Was named "AnisoPyramid" up to BornAgain 1.19.

Agrees with the "In-plane anisotropic pyramid" form factor of IsGISAXS [[manual](/lit/lazzari2006), Eq. 2.40;
[Renaud 2009](/lit/renaud2009), Eq. 217],
except for different parametrization. This is *not* the "Anisotropic pyramid"
of FitGISAXS, which is a true pyramid with an off-center apex [[Babonneau 2013](/lit/babonneau2013)].
