+++
title = "Pyramid3"
+++

### FormFactorPyramid3

A truncated pyramid (frustum) with trigonal base.

<img src="../3d/Pyramid3.png" width="30%" >
<img src="../cut/Pyramid3_xy.svg" width="30%">
<img src="../cut/Pyramid3_xz.svg" width="30%">

#### Constructor

{{< highlight python >}}
FormFactorPyramid3(L, H, alpha)
{{< /highlight >}}

Parameters:
- L, edge length of the trigonal base
- H, height
- alpha, dihedral angle $\alpha$ between the base and a side face.

Constraint:

$H \le \dfrac{\tan\alpha}{2\sqrt3} L$

The orthographic projection also shows the angle $\beta$ between the base and a side edge.
It is related to the dihedral angle through $\tan\alpha = 2\tan\beta$.

#### Usage

As for any other [Form factor](/py/sample/particle/ff).

#### Implementation

Class [FormFactorPyramid3]({{% ref-src "Sample/HardParticle/FormFactorPyramid3.h" %}})
inherits from the interface class
[IFormFactor]({{% ref-src "Sample/Particle/IFormFactor.h" %}}).

Form factor computation is based on the generic form factor of a polyhedron
provided by [libheinz](https://jugit.fz-juelich.de/mlz/libheinz).

Volume [has been validated]({{% ref-src "Tests/Unit/Sample/FormFactorBasicTest.cpp" %}})
against
$$ V=\dfrac{L^3\tan\alpha}{24}\Big[1-\Big(1-\dfrac{2\sqrt3H}{L\tan\alpha}\Big)^3\Big]. $$

#### Related shapes

More special:
- [Prism3](/py/sample/particle/ff/hard/prism3), if $\alpha=90^{\circ}$.

#### History

Was incorrectly named "Tetrahedron" up to BornAgain 1.19.

Corresponds to "Pyramid3" in IsGISAXS [[manual](/lit/lazzari2006), Eq. 2.30;
[Renaud 2009](/lit/renaud2009), Eq. 220], and as "Truncated tetrahedron" in FitGISAXS[[Babonneau 2013](/lit/babonneau2013)]. In BornAgain 1.6, redefined to let the $x$ axis lie in a mirror plane (rotated by $30^{\circ}$ with respect to the previous version).

Up to BornAgain 1.5, we computed the form factor by numeric integration, as in
IsGISAXS. Since BornAgain 1.6 higher speed and accuracy are achieved by using the
generic form factor of a polyhedron [[Wuttke 2021](/lit/wuttke2021)] with series expansions near singularities.
