+++
title = "Pyramid4"
+++

### FormFactorPyramid4

A truncated pyramid (frustum) with quadratic base.

<img src="../3d/Pyramid4.png" width="30%" >
<img src="../cut/Pyramid4_xy.svg" width="30%">
<img src="../cut/Pyramid4_xz.svg" width="30%">

#### Constructor

{{< highlight python >}}
FormFactorPyramid4(L, H, alpha)
{{< /highlight >}}

Parameters:
- L, edge length of the quadratic base
- H, height
- alpha, dihedral angle $\alpha$ between the base and a side face.

Constraint:

$H \le \dfrac{\tan\alpha}{2} L$

#### Usage

As for any other [Form factor](/py/sample/particle/ff).

#### Implementation

Class [FormFactorPyramid4]({{% ref-src "Sample/HardParticle/FormFactorPyramid4.h" %}})
inherits from the interface class
[IFormFactor]({{% ref-src "Sample/Particle/IFormFactor.h" %}}).

Form factor computation is based on the generic form factor of a polyhedron
provided by [libheinz](https://jugit.fz-juelich.de/mlz/libheinz).

Volume [has been validated]({{% ref-src "Tests/Unit/Sample/FormFactorBasicTest.cpp" %}})
against
$$ V=\dfrac{L^3\tan\alpha}{6}\Big[1-\Big(1-\dfrac{2H}{L\tan\alpha}\Big)^3\Big]. $$

#### Related shapes

More general:
- [Pyramid2](/py/sample/particle/ff/hard/pyramid2), if base is rectangular.

#### History

Was named "Pyramid" up to BornAgain 1.19.

Corresponds to "Pyramid4" form factor of IsGISAXS [[manual](/lit/lazzari2006), Eq. 2.31;
[Renaud 2009](/lit/renaud2009), Eq. 221],
except for different parametrization $L = 2R_{IsGISXAXS}$ and a corrected sign.

Reimplemented in BornAgain 1.6 using the generic form factor of a polyhedron
[[Wuttke 2021](/lit/wuttke2021)],
to achieve numerical stability near the removable singularity at $q \to 0$.
