+++
title = "Pyramid6"
+++

### FormFactorPyramid6

A truncated pyramid (frustum) based on a regular hexagon.

<img src="../3d/Pyramid6.png" width="30%" >
<img src="../cut/Pyramid6_xy.svg" width="30%">
<img src="../cut/Pyramid6_xz.svg" width="30%">

#### Constructor

{{< highlight python >}}
FormFactorPyramid6(R, H, alpha)
{{< /highlight >}}

Parameters:
- R, edge of the regular hexagonal base
- H, height
- alpha, dihedral angle $\alpha$ between the base and a side face.

Constraint:

$H \le \dfrac{\sqrt3\tan\alpha}{2} R$

Note that the orthographic projection does not show $\alpha$ but the angle $\beta$ between base and a side edge. They are related through $\sqrt3\tan\alpha = 2\tan\beta$.

#### Usage

As for any other [Form factor](/py/sample/particle/ff).

#### Implementation

Class [FormFactorPyramid6]({{% ref-src "Sample/HardParticle/FormFactorPyramid6.h" %}})
inherits from the interface class
[IFormFactor]({{% ref-src "Sample/Particle/IFormFactor.h" %}}).

Form factor computation is based on the generic form factor of a polyhedron
provided by [libheinz](https://jugit.fz-juelich.de/mlz/libheinz).

Volume [has been validated]({{% ref-src "Tests/Unit/Sample/FormFactorBasicTest.cpp" %}})
against
$$ V=\dfrac{3}{4}\tan\alpha\Big[R^3-\Big(R-\dfrac{2H}{\sqrt3\tan\alpha}\Big)^3\Big]. $$

#### Related shapes

More special:
- [Prism6](/py/sample/particle/ff/hard/prism6), if $\alpha=90^{\circ}$.

#### History

Was named "Cone6" until BornAgain 1.19.

Corresponds to "Pyramid3" in IsGISAXS [[manual](/lit/lazzari2006), Eq. 2.32;
[Renaud 2009](/lit/renaud2009), Eq. 222], and as "Truncated tetrahedron" in FitGISAXS[[Babonneau 2013](/lit/babonneau2013)]. In BornAgain 1.6, redefined to let the $x$ axis lie in a mirror plane (rotated by $30^{\circ}$ with respect to the previous version).

Up to BornAgain 1.5 by numerical integration, as in
IsGISAXS. Since BornAgain 1.6 higher speed and better accuracy are achieved by using the generic form factor of a polyhedron [[Wuttke 2021](/lit/wuttke2021)] with series expansions near singularities.
